---
title: Showcase
description: "Open source projects powered by Hextra"
toc: false
layout: wide
---

<div class="hx-mt-4"></div>

<p class="hx-mb-12 hx-text-center hx-text-lg hx-text-gray-500 dark:hx-text-gray-400">
Open source projects powered by Hextra
</p>

{{< cards >}}
  {{< card
        link="https://github.com/modelcontextprotocol/specification"
        title="Model Context Protocol Specification"
        image="https://github.com/user-attachments/assets/1bb4f952-b8fc-43b5-9cbd-cd7213c2ba90"
        imageStyle="object-fit:cover; aspect-ratio:16/9;"
  >}}

  {{< card
        link="https://github.com/jonaspleyer/cellular_raza"
        title="cellular_raza"
        image="https://github.com/user-attachments/assets/f24c6455-b70a-419b-b025-e3d60101b673"
        imageStyle="object-fit:cover; aspect-ratio:16/9;"
  >}}

  {{< card
        link="https://github.com/mightymoud/sidekick"
        title="Sidekick"
        image="https://github.com/user-attachments/assets/4ae2a9d7-77b6-42eb-a9d7-5c4599f0f812"
        imageStyle="object-fit:cover; aspect-ratio:16/9;"
  >}}

  {{< card
        link="https://github.com/welding-torch/installc"
        title="Install C"
        image="https://github.com/user-attachments/assets/c9a85327-c7e7-40f1-830a-b4190a5e47bd"
        imageStyle="object-fit:cover; aspect-ratio:16/9;"
  >}}

  {{< card
        link="https://github.com/axivo/website"
        title="AXIVO Docs"
        image="https://github.com/imfing/hextra/assets/19806136/f22f0710-23a0-430b-8bad-616283b8a3e5"
        imageStyle="object-fit:cover; aspect-ratio:16/9;"
  >}}

  {{< card
        link="https://github.com/infracourse/web"
        title="Stanford CS 40"
        image="https://github.com/imfing/hextra/assets/5097752/8c29470b-3994-41c8-be9a-5b41476e6f3c"
        imageStyle="object-fit:cover; aspect-ratio:16/9;"
  >}}

  {{< card
        link="https://github.com/helixml/docs"
        title="Helix Docs"
        image="https://github.com/imfing/hextra/assets/5097752/78045af0-4922-4358-ae73-624770909db6"
        imageStyle="object-fit:cover; aspect-ratio:16/9;"
  >}}

  {{< card
        link="https://developers.clever-cloud.com/"
        title="Clever Cloud Documentation"
        image="https://cellar-c2.services.clever-cloud.com/documentation/doc-screenshot.png" imageStyle="object-fit:cover; aspect-ratio:16/9;"
  >}}

  {{< card
        link="https://owaspai.org/"
        title="OWASP AI Security and Privacy Guide"
        image="https://github.com/imfing/hextra/assets/5097752/fbb1d3a5-a0e8-4cfc-88cf-3523b0176c89"
        imageStyle="object-fit:cover; aspect-ratio:16/9;"
  >}}

  {{< card
        link="https://developers.osuny.org"
        title="Osuny"
        image="https://raw.githubusercontent.com/noesya/osuny-developers/main/static/images/showcase-hextra/screenshot.png"
        imageStyle="object-fit:cover; aspect-ratio:16/9;"
  >}}

  {{< card link="https://porter.sh/"
        title="Porter"
        image="https://github.com/imfing/hextra/assets/5097752/401abc3a-b4c3-4336-b95a-a6dd9afbc1de"
        imageStyle="object-fit:cover; aspect-ratio:16/9;"
  >}}

  {{< card
        link="https://hoa.moe/"
        title="HITSZ OpenAuto"
        image="https://raw.githubusercontent.com/HITSZ-OpenAuto/hoa.moe/main/static/images/showcase-new.png"
        imageStyle="object-fit:cover; aspect-ratio:16/9;"
  >}}

  {{< card
        link="https://lutheranconfessions.org/"
        title="LutheranConfessions"
        image="https://github.com/imfing/hextra/assets/5097752/ad6625e4-88cd-4cad-b102-5399997d0359"
        imageStyle="object-fit:cover; aspect-ratio:16/9;"
  >}}

  {{< card
        link="https://github.com/imfing/hextra-starter-template/"
        title="Hextra Starter Template"
        image="https://user-images.githubusercontent.com/5097752/263551418-c403b9a9-a76c-47a6-8466-513d772ef0b7.jpg"
        imageStyle="object-fit:cover; aspect-ratio:16/9;"
  >}}

{{< /cards >}}
